@@ -241,11 +241,11 @@ def read_hubspot_deals(API_KEY, start_date, end_date):
     
 ## hubspot contact
 
-def read_hubspot_contact(API_KEY, start_date):
+def read_hubspot_contact(API_KEY, start_date, end_date):
     
     from askdata.integrations import hubspot_api
     
-    hubspot_contact = hubspot_api.get_hubspot_contact(API_KEY, start_date)
+    hubspot_contact = hubspot_api.get_hubspot_contact(API_KEY, start_date, end_date)
     
     return hubspot_contact
                          
